@@ -19,6 +19,7 @@
 #include "notificationserverinfo.h"
 
 #ifdef KDECONNECT_BLUETOOTH
+#include "backends/bluetooth/asynclinkprovider.h"
 #include "backends/bluetooth/bluetoothlinkprovider.h"
 #endif
 
@@ -62,39 +63,66 @@ void Daemon::init()
 {
     qCDebug(KDECONNECT_CORE) << "Daemon starting";
 
-    // Load backends
-    if (d->m_testMode)
-        d->m_linkProviders.insert(new LoopbackLinkProvider());
-    else {
-        d->m_linkProviders.insert(new LanLinkProvider());
-#ifdef KDECONNECT_BLUETOOTH
-        d->m_linkProviders.insert(new BluetoothLinkProvider());
-#endif
-#ifdef KDECONNECT_LOOPBACK
-        d->m_linkProviders.insert(new LoopbackLinkProvider());
-#endif
-    }
-
     // Register on DBus
+    // This must happen as early as possible in the process startup to ensure
+    // the absolute minimum amount of blocking on logon/autostart
+
     qDBusRegisterMetaType<QMap<QString, QString>>();
     QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.kdeconnect"));
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/modules/kdeconnect"), this, QDBusConnection::ExportScriptableContents);
 
+    qCDebug(KDECONNECT_CORE) << "DBus registration complete";
+
+    auto configInstance = KdeConnectConfig::instance();
+    const auto disabledLinkProviders = configInstance.disabledLinkProviders();
+
+    qCDebug(KDECONNECT_CORE) << "Constructing Backends";
+    // Load backends
+    if (d->m_testMode) {
+        d->m_linkProviders.insert(new LoopbackLinkProvider());
+        qCDebug(KDECONNECT_CORE) << "Constructed LoopbackLink Backend";
+    } else {
+        d->m_linkProviders.insert(new LanLinkProvider(false, disabledLinkProviders.contains(QStringLiteral("LanLinkProvider"))));
+        qCDebug(KDECONNECT_CORE) << "Constructed LanLinkProvider Backend";
+#ifdef KDECONNECT_BLUETOOTH
+        d->m_linkProviders.insert(new AsyncLinkProvider(disabledLinkProviders.contains(QStringLiteral("BluetoothLinkProvider"))));
+        qCDebug(KDECONNECT_CORE) << "Constructed AsyncLinkProvider<BluetoothLinkProvider> Backend";
+#endif
+#ifdef KDECONNECT_LOOPBACK
+        d->m_linkProviders.insert(new LoopbackLinkProvider());
+        qCDebug(KDECONNECT_CORE) << "Constructed LoopbackLinkProvider Backend";
+#endif
+    }
+    Q_EMIT linkProvidersChanged(linkProviders());
+
+    qCDebug(KDECONNECT_CORE) << "Backends loaded";
+
     // Read remembered paired devices
     const QStringList &list = KdeConnectConfig::instance().trustedDevices();
     for (const QString &id : list) {
-        addDevice(new Device(this, id));
+        Device *d = new Device(this, id);
+        // prune away devices with malformed certificates
+        if (d->hasInvalidCertificate()) {
+            qCDebug(KDECONNECT_CORE) << "Certificate for device " << id << "invalid, deleting the device";
+            KdeConnectConfig::instance().removeTrustedDevice(id);
+        } else {
+            addDevice(d);
+        }
     }
 
+    qCDebug(KDECONNECT_CORE) << "Paired devices added";
+
     // Listen to new devices
     for (LinkProvider *a : std::as_const(d->m_linkProviders)) {
         connect(a, &LinkProvider::onConnectionReceived, this, &Daemon::onNewDeviceLink);
         a->onStart();
     }
 
+    qCDebug(KDECONNECT_CORE) << "Link providers started";
+
     NotificationServerInfo::instance().init();
 
-    qCDebug(KDECONNECT_CORE) << "Daemon started";
+    qCDebug(KDECONNECT_CORE) << "Daemon start completed";
 }
 
 void Daemon::removeDevice(Device *device)
@@ -109,6 +137,7 @@ void Daemon::forceOnNetworkChange()
 {
     qCDebug(KDECONNECT_CORE) << "Sending onNetworkChange to" << d->m_linkProviders.size() << "LinkProviders";
     for (LinkProvider *a : std::as_const(d->m_linkProviders)) {
+        qCDebug(KDECONNECT_CORE) << "Sending onNetworkChange to:" << a->name();
         a->onNetworkChange();
     }
 }
@@ -128,6 +157,59 @@ QSet<LinkProvider *> Daemon::getLinkProviders() const
     return d->m_linkProviders;
 }
 
+QStringList Daemon::linkProviders() const
+{
+    auto configInstance = KdeConnectConfig::instance();
+    const auto disabledLinkProviders = configInstance.disabledLinkProviders();
+    QStringList returnValue;
+
+    for (LinkProvider *a : std::as_const(d->m_linkProviders)) {
+        QString line(a->name());
+
+        if (disabledLinkProviders.contains(a->name())) {
+            line += QStringLiteral("|disabled");
+        } else {
+            line += QStringLiteral("|enabled");
+        }
+
+        returnValue.append(line);
+    }
+    returnValue.sort();
+    return returnValue;
+}
+
+void Daemon::setLinkProviderState(const QString &linkProviderName, bool enabled)
+{
+    qCDebug(KDECONNECT_CORE) << "setLinkProviderState called" << linkProviderName << enabled;
+
+    KdeConnectConfig configInstance = KdeConnectConfig::instance();
+    LinkProvider *providerByName = nullptr;
+    const auto allLinkProviders = getLinkProviders();
+    for (LinkProvider *provider : allLinkProviders) {
+        if (provider->name() == linkProviderName) {
+            providerByName = provider;
+            break;
+        }
+    }
+
+    auto disabledLinkProviders = configInstance.disabledLinkProviders();
+    if (!enabled && !disabledLinkProviders.contains(linkProviderName)) {
+        qCDebug(KDECONNECT_CORE) << "disabling" << linkProviderName;
+        disabledLinkProviders.append(linkProviderName);
+        providerByName->disable();
+    } else if (enabled && disabledLinkProviders.contains(linkProviderName)) {
+        qCDebug(KDECONNECT_CORE) << "enabling " << linkProviderName;
+        disabledLinkProviders.removeAll(linkProviderName);
+        providerByName->enable();
+    } else {
+        qCDebug(KDECONNECT_CORE) << "No changes to the disabledLinkProviders have been made, returning";
+        return;
+    }
+
+    configInstance.setDisabledLinkProviders(disabledLinkProviders);
+    Q_EMIT linkProvidersChanged(linkProviders());
+}
+
 QStringList Daemon::devices(bool onlyReachable, bool onlyTrusted) const
 {
     QStringList ret;
@@ -180,10 +262,10 @@ void Daemon::onDeviceStatusChanged()
 {
     Device *device = (Device *)sender();
 
-    // qCDebug(KDECONNECT_CORE) << "Device" << device->name() << "status changed. Reachable:" << device->isReachable() << ". Paired: " << device->isPaired();
+    qCDebug(KDECONNECT_CORE) << "Device" << device->name() << "status changed. Reachable:" << device->isReachable() << ". Paired: " << device->isPaired();
 
     if (!device->isReachable() && !device->isPaired()) {
-        // qCDebug(KDECONNECT_CORE) << "Destroying device" << device->name();
+        qCDebug(KDECONNECT_CORE) << "Destroying device" << device->name();
         removeDevice(device);
     } else {
         Q_EMIT deviceVisibilityChanged(device->id(), device->isReachable());
