@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef PINGPLUGIN_H
-#define PINGPLUGIN_H
+#pragma once
 
 #include <QObject>
 
@@ -13,24 +12,17 @@
 
 #define PACKET_TYPE_PING QStringLiteral("kdeconnect.ping")
 
-class Q_DECL_EXPORT PingPlugin : public KdeConnectPlugin
+class PingPlugin : public KdeConnectPlugin
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.ping")
 
 public:
-    explicit PingPlugin(QObject *parent, const QVariantList &args);
-    ~PingPlugin() override;
+    using KdeConnectPlugin::KdeConnectPlugin;
 
     Q_SCRIPTABLE void sendPing();
     Q_SCRIPTABLE void sendPing(const QString &customMessage);
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override
-    {
-    }
-
+    void receivePacket(const NetworkPacket &np) override;
     QString dbusPath() const override;
 };
-
-#endif
