@@ -1,21 +1,7 @@
 /**
- * Copyright 2018 Nicolas Fella <nicolas.fella@gmx.de>
+ * SPDX-FileCopyrightText: 2018 Nicolas Fella <nicolas.fella@gmx.de>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "remotesystemvolumeplugin.h"
@@ -23,36 +9,25 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 
-#include <QDebug>
 #include <QDBusConnection>
+#include <QDebug>
 #include <QJsonArray>
 #include <QJsonDocument>
 
-#include <core/device.h>
 #include <core/daemon.h>
+#include <core/device.h>
 
 #include "plugin_remotesystemvolume_debug.h"
 
 K_PLUGIN_CLASS_WITH_JSON(RemoteSystemVolumePlugin, "kdeconnect_remotesystemvolume.json")
 
-RemoteSystemVolumePlugin::RemoteSystemVolumePlugin(QObject* parent, const QVariantList& args)
-    : KdeConnectPlugin(parent, args)
+void RemoteSystemVolumePlugin::receivePacket(const NetworkPacket &np)
 {
-}
-
-RemoteSystemVolumePlugin::~RemoteSystemVolumePlugin()
-{
-}
-
-bool RemoteSystemVolumePlugin::receivePacket(const NetworkPacket& np)
-{
-
     if (np.has(QStringLiteral("sinkList"))) {
         QJsonDocument document(np.get<QJsonArray>(QStringLiteral("sinkList")));
         m_sinks = document.toJson();
         Q_EMIT sinksChanged();
     } else {
-
         QString name = np.get<QString>(QStringLiteral("name"));
 
         if (np.has(QStringLiteral("volume"))) {
@@ -63,11 +38,9 @@ bool RemoteSystemVolumePlugin::receivePacket(const NetworkPacket& np)
             Q_EMIT mutedChanged(name, np.get<int>(QStringLiteral("muted")));
         }
     }
-
-    return true;
 }
 
-void RemoteSystemVolumePlugin::sendVolume(const QString& name, int volume)
+void RemoteSystemVolumePlugin::sendVolume(const QString &name, int volume)
 {
     NetworkPacket np(PACKET_TYPE_SYSTEMVOLUME_REQUEST);
     np.set<QString>(QStringLiteral("name"), name);
@@ -75,7 +48,7 @@ void RemoteSystemVolumePlugin::sendVolume(const QString& name, int volume)
     sendPacket(np);
 }
 
-void RemoteSystemVolumePlugin::sendMuted(const QString& name, bool muted)
+void RemoteSystemVolumePlugin::sendMuted(const QString &name, bool muted)
 {
     NetworkPacket np(PACKET_TYPE_SYSTEMVOLUME_REQUEST);
     np.set<QString>(QStringLiteral("name"), name);
@@ -83,13 +56,6 @@ void RemoteSystemVolumePlugin::sendMuted(const QString& name, bool muted)
     sendPacket(np);
 }
 
-void RemoteSystemVolumePlugin::connected()
-{
-    NetworkPacket np(PACKET_TYPE_SYSTEMVOLUME_REQUEST);
-    np.set<bool>(QStringLiteral("requestSinks"), true);
-    sendPacket(np);
-}
-
 QByteArray RemoteSystemVolumePlugin::sinks()
 {
     return m_sinks;
@@ -97,8 +63,8 @@ QByteArray RemoteSystemVolumePlugin::sinks()
 
 QString RemoteSystemVolumePlugin::dbusPath() const
 {
-    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/remotesystemvolume");
+    return QLatin1String("/modules/kdeconnect/devices/%1/remotesystemvolume").arg(device()->id());
 }
 
+#include "moc_remotesystemvolumeplugin.cpp"
 #include "remotesystemvolumeplugin.moc"
-
