@@ -4,17 +4,13 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SFTPPLUGIN_WIN_H
-#define SFTPPLUGIN_WIN_H
+#pragma once
 
 #include <core/device.h>
 #include <core/kdeconnectplugin.h>
 
 #define PACKET_TYPE_SFTP_REQUEST QStringLiteral("kdeconnect.sftp.request")
 
-static const QSet<QString> expectedFields = QSet<QString>()
-    << QStringLiteral("ip") << QStringLiteral("port") << QStringLiteral("user") << QStringLiteral("password") << QStringLiteral("path");
-;
 class SftpPlugin : public KdeConnectPlugin
 {
     Q_OBJECT
@@ -22,15 +18,11 @@ class SftpPlugin : public KdeConnectPlugin
 
 public:
     explicit SftpPlugin(QObject *parent, const QVariantList &args);
-    ~SftpPlugin() override;
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override
-    {
-    }
+    void receivePacket(const NetworkPacket &np) override;
     QString dbusPath() const override
     {
-        return QStringLiteral("/modules/kdeconnect/devices/") + deviceId + QStringLiteral("/sftp");
+        return QLatin1String("/modules/kdeconnect/devices/%1/sftp").arg(deviceId);
     }
 
 public Q_SLOTS:
@@ -39,5 +31,3 @@ public Q_SLOTS:
 private:
     QString deviceId; // Storing it to avoid accessing device() from the destructor which could cause a crash
 };
-
-#endif
